<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/tedicreations/macrame">
    <img src="https://raw.githubusercontent.com/TediCreations/macrame/master/images/logo.png" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">macrame</h3>

  <p align="center">
    Utility to build Assembly/C/C++ projects
    <br />
    <a href="https://macrame.readthedocs.io/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/tedicreations/macrame">View Demo</a>
    ·
    <a href="https://github.com/tedicreations/macrame/issues">Report Bug</a>
    ·
    <a href="https://github.com/tedicreations/macrame/issues">Request Feature</a>
  </p>
</p>

<!-- ABOUT THE PROJECT -->
## About The Project

TODO

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple steps.


### Prerequisites

TODO


### Installation

Run the following command:

```sh
pip install macrame
```

<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.


<!-- CONTACT -->
## Contact

Kanelis Ilias - [@email](mailto:hkanelhs@yahoo.gr)

GitHub Link: [https://github.com/tedicreations/macrame](https://github.com/tedicreations/macrame)

PyPi Link: [https://pypi.org/project/macrame/](https://pypi.org/project/macrame/)
